clear all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                            Michael Pokojovy                             % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1);

set(gcf, 'PaperUnits', 'centimeters');
xSize = 24; ySize = 10;
xLeft = (21 - xSize)/2; yTop = (30 - ySize)/2;
set(gcf,'PaperPosition', [xLeft yTop xSize ySize]);
set(gcf,'Position',[0 0 xSize*50 ySize*50]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M = 81;
N = 81;

M2 = ceil(M/2);
N2 = ceil(N/2);

[X, Y] = meshgrid(linspace(-4, 4, M), linspace(-4, 4, N));
Z = zeros(M, N);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 1);
hold on;

t = title('Cartesisches Gitter im Definitionsbereich', 'interpreter', 'latex');
set(t, 'FontSize', 16);

surf(X, Y, Z);
colormap pink;

axis([-4 - 0.1 4 + 0.1 -4 - 0.1 4 + 0.1]);

plot(X(1,   :), Y(end, :), 'r', 'LineWidth', 2);
plot(X(end, :), Y(1,   :), 'r', 'LineWidth', 2);
plot(X(:,   1), Y(:, end), 'r', 'LineWidth', 2);
plot(X(:, end), Y(:,   1), 'r', 'LineWidth', 2);

plot(X(M2, :),  Y(M2,  :), 'b', 'LineWidth', 2);
plot(X(:,  N2), Y(:,  N2), 'm', 'LineWidth', 2);

phi = linspace(0, 2*pi, 100);
x = cos(phi);
y = sin(phi);
plot(x, y, 'g', 'LineWidth', 2);

grid on;
view([0 90]);

xlabel('Re z');
ylabel('Im z');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 2);
hold on;

t = title('Verformtes Gitter im Bildbereich: $w = \frac{z - i}{z + i}$', 'interpreter', 'latex');
set(t, 'FontSize', 16);

W = (X + i*Y - i)./(X + i*Y + i);
U = real(W);
V = imag(W);
Z = zeros(M, N);

surf(U, V, Z);
colormap pink;

plot(U(1,   :), V(1,   :), 'r', 'LineWidth', 2);
plot(U(end, :), V(end, :), 'r', 'LineWidth', 2);
plot(U(:,   1), V(:,   1), 'r', 'LineWidth', 2);
plot(U(:, end), V(:, end), 'r', 'LineWidth', 2);

plot(U(M2, :),  V(M2,  :), 'b', 'LineWidth', 2);
plot(U(:,  N2), V(:,  N2), 'm', 'LineWidth', 2);

W = (x + i*y - i)./(x + i*y + i);
plot(real(W), imag(W), 'g', 'LineWidth', 2);

grid on;
view([0 90]);
axis([-3.5 3.5 -3.5 3.5]);

xlabel('Re w');
ylabel('Im w');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%