clear all
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                            Michael Pokojovy                             % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1);

set(gcf, 'PaperUnits', 'centimeters');
xSize = 24; ySize = 10;
xLeft = (21 - xSize)/2; yTop = (30 - ySize)/2;
set(gcf,'PaperPosition', [xLeft yTop xSize ySize]);
set(gcf,'Position',[0 0 xSize*50 ySize*50]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
a = 2*exp(i*pi/3);
b = sqrt(3)*exp(-i*pi/4);

M = 81;
N = 81;

M2 = ceil(M/2);
N2 = ceil(N/2);

[R, PHI] = meshgrid(linspace(1E-3, 3.5, M), linspace(0, 2*pi, N));

X = -real(conj(a/b)) + R.*cos(PHI);
Y = -imag(conj(a/b)) + R.*sin(PHI);

Z = zeros(M, N);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 1);
hold on;

t = title('Krummliniges Gitter im Definitionsbereich', 'interpreter', 'latex');
set(t, 'FontSize', 16);

surf(X, Y, Z);
colormap pink;

axis([-1.5 - 0.01 1.5 + 0.01 -1.5 - 0.01 1.5 + 0.01]);

plot(X(1,   :), Y(end, :), 'r', 'LineWidth', 2);
plot(X(end, :), Y(1,   :), 'r', 'LineWidth', 2);
plot(X(:,   1), Y(:, end), 'r', 'LineWidth', 2);
plot(X(:, end), Y(:,   1), 'r', 'LineWidth', 2);

plot(X(M2, :),  Y(N2,  :), 'b', 'LineWidth', 2);
plot(X(:,  N2), Y(:,  N2), 'm', 'LineWidth', 2);

plot(0, 0, 'y*', 'MarkerSize', 10, 'LineWidth', 5);
text(0.1, -0.1, '$z = 0$', 'interpreter', 'latex', 'FontSize', 16, 'Color', 'Yellow');

phi = linspace(0, 2*pi, 500);
x = cos(phi);
y = sin(phi);
plot(x, y, 'g', 'LineWidth', 2);

grid on;
view([0 90]);

xlabel('Re z');
ylabel('Im z');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 2);
hold on;

t = title('Verformtes Gitter im Bildbereich: $w = \frac{a z + b}{\bar{b} z + \bar{a}}$, $a = 2 e^{i \pi/3}, b = \sqrt{3} e^{-i \pi/4}$', 'interpreter', 'latex');
set(t, 'FontSize', 16);

W = (a*(X + i*Y) + b)./(conj(b)*(X + i*Y) + conj(a));

U = real(W);
V = imag(W);
Z = zeros(M, N);

surf(U, V, Z);
colormap pink;

plot(U(1,   :), V(1,   :), 'r', 'LineWidth', 2);
plot(U(end, :), V(end, :), 'r', 'LineWidth', 2);
plot(U(:,   1), V(:,   1), 'r', 'LineWidth', 2);
plot(U(:, end), V(:, end), 'r', 'LineWidth', 2);

plot(U(M2, :),  V(M2,  :), 'b', 'LineWidth', 2);
plot(U(:,  N2), V(:,  N2), 'm', 'LineWidth', 2);

W = (a*(x + i*y) + b)./(conj(b)*(x + i*y) + conj(a));
plot(real(W), imag(W), 'g', 'LineWidth', 2);

w = b/conj(a);
plot(real(w), imag(w), 'y*', 'MarkerSize', 10, 'LineWidth', 5);
text(real(w) - 1, imag(w), '$w = \frac{\sqrt{3}}{2} e^{i \pi/12}$', 'interpreter', 'latex', 'FontSize', 16, 'Color', 'Yellow');

grid on;
view([0 90]);
axis([-1.5 - 0.01 1.5 + 0.01 -1.5 - 0.01 1.5 + 0.01]);

xlabel('Re w');
ylabel('Im w');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%