%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                            Michael Pokojovy                             % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1);

set(gcf, 'PaperUnits', 'centimeters');
xSize = 24; ySize = 10;
xLeft = (21 - xSize)/2; yTop = (30 - ySize)/2;
set(gcf,'PaperPosition', [xLeft yTop xSize ySize]);
set(gcf,'Position',[0 0 xSize*50 ySize*50]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
M = 51;
N = 51;

M2 = ceil(M/2);
N2 = ceil(N/2);

[R, PHI] = meshgrid(linspace(0, 2, M), linspace(1E-5, 2*pi - 1E-5, N));
X = R.*abs(cos(PHI)).^(1/3).*sign(cos(PHI));
Y = R.*abs(sin(PHI)).^(1/3).*sign(sin(PHI));
Z = zeros(M, N);

R = sqrt(X.^2 + Y.^2);
PHI = (Y >= 0).*(acos(X./R)) + (Y < 0).*(2*pi - acos(X./R));

Z = zeros(M, N);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 1);
hold on;

t = title('Krummliniges Gitter im Definitionsbereich', 'interpreter', 'latex');
set(t, 'FontSize', 16);

surf(X, Y, Z);
colormap pink;

axis([-2 - 0.1 2 + 0.1 -2 - 0.1 2 + 0.1]);

plot(X(1,   :), Y(1,   :), 'r', 'LineWidth', 2);
plot(X(end, :), Y(end, :), 'r', 'LineWidth', 2);
plot(X(:,   1), Y(:,   1), 'r', 'LineWidth', 2);
plot(X(:, end), Y(:, end), 'r', 'LineWidth', 2);

plot(X(M2, :),  Y(M2,  :), 'b', 'LineWidth', 2);
plot(X(:,  N2), Y(:,  N2), 'm', 'LineWidth', 2);

grid on;
view([0 90]);

xlabel('Re z');
ylabel('Im z');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(1, 2, 2);
hold on;

t = title('Verformtes Gitter im Bildbereich: $w = \sqrt[3]{z}$', 'interpreter', 'latex');
set(t, 'FontSize', 16);


W = R.^(1/3).*exp(i*PHI/3);
U = real(W);
V = imag(W);
Z = zeros(M, N);

surf(U, V, Z);
colormap pink;

plot(U(1,   :), V(1,   :), 'r', 'LineWidth', 2);
plot(U(end, :), V(end, :), 'r', 'LineWidth', 2);
plot(U(:,   1), V(:,   1), 'r', 'LineWidth', 2);
plot(U(:, end), V(:, end), 'r', 'LineWidth', 2);

plot(U(M2, :),  V(M2,  :), 'b', 'LineWidth', 2);
plot(U(:,  N2), V(:,  N2), 'm', 'LineWidth', 2);

axis([-1.4 1.4 -1.4 1.4]);

grid on;
view([0 90]);

xlabel('Re w');
ylabel('Im w');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%